Generate the matrix W as seen in equation 8 for use in the function.
generate_my_w(X = matrix(), Z = matrix())Generated W matrix nrow(X) by (ncol(X)+ncol(X) by ncol(Z))
N by p matrix of predictors
N by nz matrix of modifying variables. The elements of z may represent quantitative or categorical variables, or a mixture of the two. Categorical variables should be coded by 0-1 dummy variables: for a k-level variable, one can use either k or k-1 dummy variables.