Compute predicted values from a MADMMplasso object. Make predictions from a fitted MADMMplasso model
# S3 method for MADMMplasso
predict(object, X, Z, y, lambda = NULL, ...)predicted values
object returned from a call to MADMMplasso
N by p matrix of predictors
N by nz matrix of modifying variables. These may be observed or the predictions from a supervised learning algorithm that predicts z from test features x and possibly other features.
N by D matrix of responses.
values of lambda at which predictions are desired. If NULL (default), the path of lambda values from the fitted model. are used. If lambda is not NULL, the predictions are made at the closest values to lambda in the lambda path from the fitted model
additional arguments to the generic predict() method